#!/bin/bash

# PKGHOME: http://www.twobarleycorns.net/tkcvs.html
# AUTHOR: fdeak <ferenc.deak@gmail.com>
# NOTES: The tkcvs.png is converted by the pkg author with imagemagick
# NOTES:  $convert tkcvs/bitmaps/tkcvs48.xbm tkcvs48.png
# DEPENDS: tcl tk

soft='tkcvs'
softversion='8.0.3'
packageversion='44.1'

arch='noarch'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/${soft}_${softversion//./_}.tar.gz"
src="$buildir/${soft}_${softversion//./_}"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"
numjobs='-j2'

set -e
cd $buildir
rm -rf $src
tar xzf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
chown -R root:root .

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

cd $src

# Build & install the pkg
./doinstall.tcl -nox $dest/usr
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
cp $buildir/tkcvs48.png $dest/usr/share/icons/hicolor/48x48/apps/tkcvs.png

# Strip binaries and libraries
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress man pages
( cd $dest/usr/man
  find . -type f -exec gzip -9 {} \;
  for i in `find . -type l` ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
)

# Install docs
mkdir -p $dest/usr/doc/$soft-$softversion
cp -a FAQ COPYING CHANGELOG \
  $dest/usr/doc/$soft-$softversion
cp tkdiff/Changelog $dest/usr/doc/$soft-$softversion/tkdiff-Changelog
cp tkdiff/COPYING $dest/usr/doc/$soft-$softversion/tkdiff-COPYING


mkdir -p $dest/usr/share/applications
cat << "EOF" > $dest/usr/share/applications/$soft.desktop
[Desktop Entry]
Name=tkcvs
Comment=Graphical Interface to CVS and Subversion
Exec=tkcvs
Icon=tkcvs
Terminal=false
Type=Application
Categories=Application;Development
StartupNotify=false
Encoding=UTF-8
EOF

# Save the build script
mkdir -p $dest/usr/src/$soft-$softversion
( cd $buildir; cp -a build-$soft.sh $dest/usr/src/$soft-$softversion/ )

# Create the /install directory
mkdir -p $dest/install
cat > $dest/install/slack-desc << END
     |-----handy-ruler------------------------------------------------------|
tkcvs: tkcvs - a Tk/Tcl Graphical Interface to CVS and Subversion
tkcvs: 
tkcvs: TkCVS  is  a Tcl/Tk-based graphical interface to the CVS and
tkcvs: Subversion configuration management systems. It displays the status of
tkcvs: the files in the current working directory, and provides buttons and
tkcvs: menus to execute configuration-management  commands on the selected
tkcvs: files.  Limited RCS functionality is also present.  TkDiff is bundled
tkcvs: in for browsing and merging your changes.
tkcvs: 
tkcvs: 
tkcvs: 
END

# Create the slackware package
cd $dest
/sbin/makepkg -l y -c n $dest.tgz
(cd $buildir; md5sum $package.tgz > $package.md5)

